'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ramda;

function _load_ramda() {
  return _ramda = _interopRequireDefault(require('ramda'));
}

var _globalConfig;

function _load_globalConfig() {
  return _globalConfig = require('../api/consumer/lib/global-config');
}

var _client;

function _load_client() {
  return _client = _interopRequireDefault(require('./http-client/client'));
}

var _logger;

function _load_logger() {
  return _logger = _interopRequireDefault(require('../logger/logger'));
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function stringifyIfNeeded(val) {
  return typeof val === 'string' ? val : JSON.stringify(val);
}

var createHook = function createHook(hookNameKey, methodName) {
  (_logger || _load_logger()).default.debug(`Creating a hook ${hookNameKey} with a method ${methodName}`);
  methodName = (_ramda || _load_ramda()).default.toUpper(methodName);
  return function (data) {
    return new Promise(function (resolve) {
      return (0, (_globalConfig || _load_globalConfig()).get)(hookNameKey).then(function (destUrl) {
        if (!destUrl) {
          (_logger || _load_logger()).default.warn(`Failed running the ${hookNameKey} hook as destUrl is not set in the config file. hook data: ${stringifyIfNeeded(data)}`);

          return resolve();
        }
        (_logger || _load_logger()).default.debug(`Running the ${hookNameKey} hook with destUrl: ${destUrl}, and data: ${stringifyIfNeeded(data)}`);
        return (_client || _load_client()).default[methodName](destUrl, data).then(function () {
          (_logger || _load_logger()).default.debug(`Successfully ran hook ${hookNameKey}`);
          return resolve();
        }).catch(function (err) {
          (_logger || _load_logger()).default.warn(`Failed running the hook ${hookNameKey}. Error: ${stringifyIfNeeded(err)}`);
          return resolve();
        });
      });
    });
  };
};

exports.default = createHook;
//# sourceMappingURL=create-hook.js.map